@@ -30,7 +30,7 @@ class FilterActionMissingTemplateDialog : public QDialog
 public:
     explicit FilterActionMissingTemplateDialog(const QStringList &templateList, const QString &filtername, QWidget *parent = nullptr);
     ~FilterActionMissingTemplateDialog();
-    QString selectedTemplate() const;
+    Q_REQUIRED_RESULT QString selectedTemplate() const;
 
 private:
     void readConfig();
