@@ -37,15 +37,15 @@ class FilterActionPlaySound : public FilterActionWithTest
 public:
     FilterActionPlaySound();
     ~FilterActionPlaySound();
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    SearchRule::RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
     static FilterAction *newAction();
-    bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) override;
+    Q_REQUIRED_RESULT bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) override;
 
-    bool isEmpty() const override;
-    QString informationAboutNotValidAction() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
+    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 private:
-    mutable Phonon::MediaObject *mPlayer;
+    mutable Phonon::MediaObject *mPlayer = nullptr;
 };
 }
 
