@@ -26,14 +26,14 @@ class FilterActionUnsetStatus : public FilterActionStatus
     Q_OBJECT
 public:
     explicit FilterActionUnsetStatus(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    SearchRule::RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
 
     static FilterAction *newAction();
-    QString sieveCode() const override;
-    QStringList sieveRequires() const override;
-    bool isEmpty() const override;
-    QString informationAboutNotValidAction() const override;
+    Q_REQUIRED_RESULT QString sieveCode() const override;
+    Q_REQUIRED_RESULT QStringList sieveRequires() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
+    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 private:
     bool checkIsValid(int &index) const;
 };
