@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 
 #include "mailcommon_private_export.h"
 
-namespace MailCommon
-{
+namespace MailCommon {
 class MailFilter;
 class MAILCOMMON_TESTS_EXPORT KMFilterAccountList : public QTreeWidget
 {
