@@ -89,10 +89,10 @@ public:
     /**
     * Returns the unique identifier of this filter.
     */
-    QString identifier() const;
+    Q_REQUIRED_RESULT QString identifier() const;
 
     /** Equivalent to @pattern()->name(). @return name of the filter */
-    QString name() const;
+    Q_REQUIRED_RESULT QString name() const;
 
     /** Execute the filter action(s) on the given message.
       Returns:
@@ -105,21 +105,21 @@ public:
       true if the caller may apply other filters and false if he shall
       stop the filtering of this message.
     */
-    ReturnCode execActions(ItemContext &context, bool &stopIt, bool applyOnOutbound) const;
+    Q_REQUIRED_RESULT ReturnCode execActions(ItemContext &context, bool &stopIt, bool applyOnOutbound) const;
 
     /**
     * Returns the required part from the item that is needed for the filter to
     * operate. See @ref SearchRule::RequiredPart */
-    SearchRule::RequiredPart requiredPart(const QString &id) const;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart(const QString &id) const;
 
     /** Write contents to given config group. */
     void writeConfig(KConfigGroup &config, bool exportFilter) const;
 
     /** Initialize from given config group. */
-    bool readConfig(const KConfigGroup &config, bool interactive = false);
+    Q_REQUIRED_RESULT bool readConfig(const KConfigGroup &config, bool interactive = false);
 
     /** Remove empty rules (and actions one day). */
-    QString purify(bool removeAction = true);
+    Q_REQUIRED_RESULT QString purify(bool removeAction = true);
 
     /** Check for empty pattern and action list. */
     bool isEmpty() const;
@@ -135,7 +135,7 @@ public:
     /** Provides a reference to the internal pattern. If you used the
       @p matches() function before, please convert to using
       myFilter->pattern()->matches() now. */
-    SearchPattern *pattern();
+    Q_REQUIRED_RESULT SearchPattern *pattern();
 
     /** Provides a reference to the internal pattern. If you used the
       @p matches() function before, please convert to using
@@ -146,13 +146,13 @@ public:
       outbound messages (@p aApply == true) or not.
       See applyOnOutbound applyOnInbound setApplyOnInbound
     */
-    void setApplyOnOutbound(bool aApply = true);
+    void setApplyOnOutbound(bool aApply);
 
     /** Set whether this filter should be applied on
       outbound messages before sending (@p aApply == TRUE) or not.
       See applyOnOutbound applyOnInbound setApplyOnInbound
     */
-    void setApplyBeforeOutbound(bool aApply = true);
+    void setApplyBeforeOutbound(bool aApply);
 
     /** @return true if this filter should be applied on
       outbound messages, false otherwise.
@@ -170,7 +170,7 @@ public:
       inbound messages (@p aApply == true) or not.
       @see setApplyOnOutbound applyOnInbound applyOnOutbound
     */
-    void setApplyOnInbound(bool aApply = true);
+    void setApplyOnInbound(bool aApply);
 
     /** @return true if this filter should be applied on
       inbound messages, false otherwise.
@@ -182,7 +182,7 @@ public:
       explicit (CTRL-J) filtering (@p aApply == true) or not.
       @see setApplyOnOutbound applyOnInbound applyOnOutbound
     */
-    void setApplyOnExplicit(bool aApply = true);
+    void setApplyOnExplicit(bool aApply);
 
     /** @return true if this filter should be applied on
       explicit (CTRL-J) filtering, false otherwise.
@@ -199,6 +199,16 @@ public:
     */
     void setApplicability(AccountType aApply = All);
 
+    /** Sets whether the filter should be applied on inbound emails in all
+      folders, not just Inbox.
+    */
+    void setApplyOnAllFoldersInbound(bool aApply);
+
+    /** Returns whether the filter should be applied on inbound emails in all
+      folders, not just Inbox.
+    */
+    bool applyOnAllFoldersInbound() const;
+
     /** @return true if this filter should be applied on
       inbound messages for all accounts, or false if this filter
       is to be applied on a specified set of accounts only.
@@ -327,6 +337,7 @@ private:
     bool bApplyBeforeOutbound : 1;
     bool bApplyOnOutbound : 1;
     bool bApplyOnExplicit : 1;
+    bool bApplyOnAllFolders : 1;
     bool bStopProcessingHere : 1;
     bool bConfigureShortcut : 1;
     bool bConfigureToolbar : 1;
