@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,15 +28,13 @@
 
 class QAbstractItemModel;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class ChangeRecorder;
 class Collection;
 class Session;
 }
 
-namespace MailCommon
-{
+namespace MailCommon {
 class FolderCollectionMonitorPrivate;
 class MAILCOMMON_EXPORT FolderCollectionMonitor : public QObject
 {
@@ -46,19 +44,17 @@ public:
     explicit FolderCollectionMonitor(Akonadi::Session *session, QObject *parent = nullptr);
     ~FolderCollectionMonitor();
 
-    Akonadi::ChangeRecorder *monitor() const;
+    Q_REQUIRED_RESULT Akonadi::ChangeRecorder *monitor() const;
     void expireAllFolders(bool immediate, QAbstractItemModel *collectionModel);
     void expunge(const Akonadi::Collection &, bool sync = false);
 
 protected:
-    void expireAllCollection(const QAbstractItemModel *model, bool immediate,
-                             const QModelIndex &parentIndex = QModelIndex());
+    void expireAllCollection(const QAbstractItemModel *model, bool immediate, const QModelIndex &parentIndex = QModelIndex());
 
 private:
     void slotDeleteJob(KJob *job);
     FolderCollectionMonitorPrivate *const d;
 };
-
 }
 
 #endif
