@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -76,7 +76,7 @@ static struct _statusNames statusNames[] = {
 static const int numStatusNames
     = sizeof statusNames / sizeof(struct _statusNames);
 
-QString englishNameForStatus(const Akonadi::MessageStatus &status)
+QString englishNameForStatus(Akonadi::MessageStatus status)
 {
     for (int i = 0; i < numStatusNames; ++i) {
         if (statusNames[i].status == status) {
