@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,8 +36,8 @@ public:
     ~AddTagDialog();
 
     void setTags(const QList<MailCommon::Tag::Ptr> &tags);
-    QString label() const;
-    Akonadi::Tag tag() const;
+    Q_REQUIRED_RESULT QString label() const;
+    Q_REQUIRED_RESULT Akonadi::Tag tag() const;
 
 private:
     void slotSave();
