@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,12 +20,11 @@
 
 #include <KConfigGroup>
 #include <QString>
-#include "pimcommon_export.h"
+#include "mailcommon_export.h"
 
-namespace PimCommon
-{
+namespace MailCommon {
 class ResourceReadConfigFilePrivate;
-class PIMCOMMON_EXPORT ResourceReadConfigFile
+class MAILCOMMON_EXPORT ResourceReadConfigFile
 {
 public:
     ResourceReadConfigFile(const QString &resourceName);
